@@ -110,7 +110,7 @@ void BandPassBox::fromDomElement(const QDomElement &e)
     }
 }
 
-void BandPassBox::render(QPainter *painter, const QRectF &area)
+void BandPassBox::render(QPainter *painter, const QRectF &area) const
 {
     if (!painter)
         return;
