@@ -30,6 +30,16 @@ int main(int argc, char *argv[])
 
     MainWindow w; /* must be created _after_ setSavePath */
 
+    QString iconpath = QString(DATADIR "/pixmaps/" TARGET ".png");
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+    if (QFileInfo::exists(iconpath))
+#else
+    if ((QFileInfo(iconpath)).exists())
+#endif
+        w.setWindowIcon(QIcon(iconpath));
+    else
+        w.setWindowIcon(QIcon(TARGET ".png"));
+
     if (argc > 1)
         w.setWindowFilePath(argv[argc - 1]);
 
