@@ -1,3 +1,4 @@
+#include <iostream>
 #include <QtCore>
 #include <QDebug>
 #include <QMessageBox>
@@ -13,6 +14,7 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
+#include "speaker.h"
 #include "speakerdb.h"
 #include "importexport.h"
 #include "plot.h"
@@ -26,17 +28,17 @@ MainWindow::MainWindow(QWidget *parent) :
     ui(new Ui::MainWindow),
     projectSaved(false),
     isModifying(false),
-    spkDialog(NULL),
-    fileDialog(NULL),
-    searchDialog(NULL),
-    listDialog(NULL),
-    bandpassDialog(NULL),
+    spkDialog(nullptr),
+    fileDialog(nullptr),
+    searchDialog(nullptr),
+    listDialog(nullptr),
+    bandpassDialog(nullptr),
     currentSpeakerNumber(0),
     currentTabIndex(-1),
-    sealedPlot(NULL),
-    portedPlot(NULL),
-    bandpassPlot(NULL),
-    notInDbSpeaker(NULL)
+    sealedPlot(nullptr),
+    portedPlot(nullptr),
+    bandpassPlot(nullptr),
+    notInDbSpeaker(nullptr)
 {
     ui->setupUi(this);
 
@@ -175,6 +177,9 @@ void MainWindow::onProjectImport()
 
     linkInternals();
     linkTabs();
+
+    if (notInDbSpeaker)
+        onSpeakerModify();
 }
 
 void MainWindow::onProjectQuit()
@@ -221,7 +226,8 @@ void MainWindow::syncUiFromCurrentSpeaker(const Speaker& spk)
         ui->modelComboBox->clear();
         ui->modelComboBox->addItems(SpeakerDb::getModelsByVendor(spk.getVendor()));
 
-        for (int i = 0; i < speakers.count(); i++) {
+        int i = 0;
+        for (i = 0; i < speakers.count(); i++) {
             Speaker speaker = speakers[i];
             if (speaker.getModel() == spk.getModel()) {
                 if (speaker != spk) {
@@ -233,18 +239,27 @@ void MainWindow::syncUiFromCurrentSpeaker(const Speaker& spk)
                 } else {
                     /* okay, select correct combo */
                     ui->modelComboBox->setCurrentIndex(ui->modelComboBox->findText(spk.getModel()));
-                    notInDbSpeaker = NULL;
+                    notInDbSpeaker = nullptr;
                 }
+
+                break;
             }
         }
+
+        if (i == speakers.count()) {
+            /* vendor was ok but model was not in DB */
+            ui->modelComboBox->addItem(spk.getModel());
+            ui->modelComboBox->setCurrentIndex(ui->modelComboBox->findText(spk.getModel()));
+            notInDbSpeaker = &spk;
+        }
     }
 
     /* display speaker's values */
     ui->fsValueLabel->setNum(currentSpeaker.getFs());
     ui->qtsValueLabel->setNum(currentSpeaker.getQts());
     ui->vasValueLabel->setNum(currentSpeaker.getVas());
-    ui->sdValueLabel->setNum(currentSpeaker.getSd());
-    ui->reValueLabel->setNum(currentSpeaker.getRe());
+    ui->diaValueLabel->setNum(currentSpeaker.getDia());
+    ui->zValueLabel->setNum(currentSpeaker.getZ());
 }
 
 void MainWindow::syncUiFromCurrentSealedBox(const SealedBox& box)
@@ -371,8 +386,8 @@ void MainWindow::onBandpassOptimizeRequested(double s, double pa)
     disconnect(bandpassDialog, SIGNAL(optimizeRequested(double,double)), this, SLOT(onBandpassOptimizeRequested(double,double)));
     disconnect(bandpassDialog, SIGNAL(optimizeCancelled()), this, SLOT(onBandpassOptimizeCancelled()));
     bandpassDialog->close();
-    delete bandpassDialog;
-    bandpassDialog = NULL;
+    bandpassDialog->deleteLater();
+    bandpassDialog = nullptr;
 }
 
 void MainWindow::onBandpassOptimizeCancelled()
@@ -380,8 +395,8 @@ void MainWindow::onBandpassOptimizeCancelled()
     disconnect(bandpassDialog, SIGNAL(optimizeRequested(double,double)), this, SLOT(onBandpassOptimizeRequested(double,double)));
     disconnect(bandpassDialog, SIGNAL(optimizeCancelled()), this, SLOT(onBandpassOptimizeCancelled()));
     bandpassDialog->close();
-    delete bandpassDialog;
-    bandpassDialog = NULL;
+    bandpassDialog->deleteLater();
+    bandpassDialog = nullptr;
 }
 
 void MainWindow::linkMenus()
@@ -519,6 +534,15 @@ void MainWindow::onSpeakerRemove()
     }
 
     SpeakerDb::removeByVendorAndModel(vendor, model);
+
+    /* fill speakers of automatically reselected vendor */
+    QString v = ui->vendorComboBox->currentText();
+    ui->modelComboBox->clear();
+    ui->modelComboBox->addItems(SpeakerDb::getModelsByVendor(v));
+    /* insert a fake speaker to let the choice to the user */
+    ui->modelComboBox->insertItem(0, "?");
+    ui->modelComboBox->setCurrentIndex(0);
+    setCurrentSpeaker(Speaker());
 }
 
 void MainWindow::onSpeakerModify()
@@ -549,11 +573,14 @@ void MainWindow::onSpeakerInserted(Speaker spk)
             ui->modelComboBox->addItem(spk.getModel());
     }
 
+    /* spk has been inserted or modified: remove anyway notInDbSpeaker */
+    notInDbSpeaker = nullptr;
+
     disconnect(spkDialog, SIGNAL(speakerInserted(Speaker)), this, SLOT(onSpeakerInserted(Speaker)));
     disconnect(spkDialog, SIGNAL(speakerCancelled()), this, SLOT(onSpeakerCancelled()));
     spkDialog->close();
-    delete spkDialog;
-    spkDialog = NULL;
+    spkDialog->deleteLater();
+    spkDialog = nullptr;
 }
 
 void MainWindow::onSpeakerCancelled()
@@ -561,8 +588,8 @@ void MainWindow::onSpeakerCancelled()
     disconnect(spkDialog, SIGNAL(speakerInserted(Speaker)), this, SLOT(onSpeakerInserted(Speaker)));
     disconnect(spkDialog, SIGNAL(speakerCancelled()), this, SLOT(onSpeakerCancelled()));
     spkDialog->close();
-    delete spkDialog;
-    spkDialog = NULL;
+    spkDialog->deleteLater();
+    spkDialog = nullptr;
 }
 
 void MainWindow::onEditOptimize()
@@ -661,9 +688,9 @@ void MainWindow::onAboutAbout()
 {
     QMessageBox::about(this, tr("About QSpeakers"),
                        tr("QSpeakers version " VERSION "\n\n"
-                          "This program simulates common acoustical enclosures behaviour to help designing loudspeaker systems.\n\n"
-                          "This program is free software, copyright (C) 2014 Benoit Rouits <brouits@free.fr> and released under the GNU General Public Lisence "
-                          "version 3. It is delivered as is in the hope it can be useful, but with no warranty of correctness."));
+                                                       "This program simulates common acoustical enclosures behaviour to help designing loudspeaker systems.\n\n"
+                                                       "This program is free software, copyright (C) 2014 Benoit Rouits <brouits@free.fr> and released under the GNU General Public Lisence "
+                                                       "version 3. It is delivered as is in the hope it can be useful, but with no warranty of correctness."));
 }
 
 void MainWindow::onSearchRequested(const QString& param, double min, double max)
@@ -671,11 +698,10 @@ void MainWindow::onSearchRequested(const QString& param, double min, double max)
     disconnect(searchDialog, SIGNAL(searchRequested(const QString&, double, double)), this, SLOT(onSearchRequested(const QString&, double, double)));
     disconnect(searchDialog, SIGNAL(searchCancelled()), this, SLOT(onSearchCancelled()));
     searchDialog->close();
-    delete searchDialog;
-    searchDialog = NULL;
+    searchDialog->deleteLater();
+    searchDialog = nullptr;
 
     QList<Speaker> speakers = SpeakerDb::getByValue(param, min, max);
-
     listDialog = new ListDialog(speakers, this);
     connect(listDialog, SIGNAL(speakerItemSelected(QString, const Speaker&)), this, SLOT(onSpeakerItemSelected(QString, const Speaker&)));
     connect(listDialog, SIGNAL(speakerItemCancelled()), this, SLOT(onSpeakerItemCancelled()));
@@ -687,8 +713,8 @@ void MainWindow::onSearchCancelled()
     disconnect(searchDialog, SIGNAL(searchRequested(const QString&, double, double)), this, SLOT(onSearchRequested(const QString&, double, double)));
     disconnect(searchDialog, SIGNAL(searchCancelled()), this, SLOT(onSearchCancelled()));
     searchDialog->close();
-    delete searchDialog;
-    searchDialog = NULL;
+    searchDialog->deleteLater();
+    searchDialog = nullptr;
 }
 
 void MainWindow::onSpeakerItemSelected(QString title, const Speaker& speaker)
@@ -702,8 +728,8 @@ void MainWindow::onSpeakerItemSelected(QString title, const Speaker& speaker)
     disconnect(listDialog, SIGNAL(speakerItemSelected(QString, const Speaker&)), this, SLOT(onSpeakerItemSelected(QString, const Speaker&)));
     disconnect(listDialog, SIGNAL(speakerItemCancelled()), this, SLOT(onSpeakerItemCancelled()));
     listDialog->close();
-    delete listDialog;
-    listDialog = NULL;
+    listDialog->deleteLater();
+    listDialog = nullptr;
 }
 
 void MainWindow::onSpeakerItemCancelled()
@@ -711,8 +737,8 @@ void MainWindow::onSpeakerItemCancelled()
     disconnect(listDialog, SIGNAL(speakerItemSelected(QString,const Speaker&)), this, SLOT(onSpeakerItemSelected(QString,const Speaker&)));
     disconnect(listDialog, SIGNAL(speakerItemCancelled()), this, SLOT(onSpeakerItemCancelled()));
     listDialog->close();
-    delete listDialog;
-    listDialog = NULL;
+    listDialog->deleteLater();
+    listDialog = nullptr;
 }
 
 void MainWindow::setActivateActions(QList<QAction*> actions, bool enable)
@@ -782,13 +808,26 @@ void MainWindow::onVendorChanged(QString vendor)
 {
 
     if (notInDbSpeaker) {
+        if (vendor == notInDbSpeaker->getVendor())
+            return;
+
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Unsaved speaker"),
-                              tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
-                              QMessageBox::Yes|QMessageBox::No);
+                                      tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
+                                      QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::Yes) {
             SpeakerDb::insertOrReplace(notInDbSpeaker->getVendor(), notInDbSpeaker->getModel(), *notInDbSpeaker);
-            notInDbSpeaker = NULL;
+            notInDbSpeaker = nullptr;
+        } else /* no insert wanted */ {
+            if (0 == SpeakerDb::getByVendor(notInDbSpeaker->getVendor()).count()) {
+                /* forget entries */
+                ui->vendorComboBox->removeItem(ui->vendorComboBox->findText(notInDbSpeaker->getVendor()));
+                ui->modelComboBox->removeItem(ui->modelComboBox->findText(notInDbSpeaker->getModel()));
+            } else {
+                /* forget model */
+                ui->modelComboBox->removeItem(ui->modelComboBox->findText(notInDbSpeaker->getModel()));
+            }
+            notInDbSpeaker = nullptr;
         }
     }
 
@@ -807,16 +846,30 @@ void MainWindow::onModelChanged(QString model)
         return;
 
     if (notInDbSpeaker) {
+        if (model == notInDbSpeaker->getModel())
+            return;
+
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Unsaved speaker"),
-                              tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
-                              QMessageBox::Yes|QMessageBox::No);
+                                      tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
+                                      QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::Yes) {
             SpeakerDb::insertOrReplace(notInDbSpeaker->getVendor(), notInDbSpeaker->getModel(), *notInDbSpeaker);
-            notInDbSpeaker = NULL;
+            notInDbSpeaker = nullptr;
+        } else /* no insert wanted */ {
+            if (0 == SpeakerDb::getByVendor(notInDbSpeaker->getVendor()).count()) {
+                /* forget entries */
+                ui->vendorComboBox->removeItem(ui->vendorComboBox->findText(notInDbSpeaker->getVendor()));
+                ui->modelComboBox->removeItem(ui->modelComboBox->findText(notInDbSpeaker->getModel()));
+            } else {
+                /* forget model */
+                ui->modelComboBox->removeItem(ui->modelComboBox->findText(notInDbSpeaker->getModel()));
+            }
+            notInDbSpeaker = nullptr;
         }
     }
 
+    /* change model */
     if ((ui->modelComboBox->findText("?") == 0) && (ui->modelComboBox->currentIndex() != 0)) {
         /* user choose a speaker; safely remove fake speaker */
         ui->modelComboBox->removeItem(0);
@@ -831,8 +884,8 @@ void MainWindow::onCurrentSpeakerChanged(const Speaker &spk)
     ui->fsValueLabel->setNum(spk.getFs());
     ui->qtsValueLabel->setNum(spk.getQts());
     ui->vasValueLabel->setNum(spk.getVas());
-    ui->sdValueLabel->setNum(spk.getSd());
-    ui->reValueLabel->setNum(spk.getRe());
+    ui->diaValueLabel->setNum(spk.getDia());
+    ui->zValueLabel->setNum(spk.getZ());
 
     /* the user may have activated the "?" fake speaker */
     if (!spk.isValid()) {
