@@ -8,6 +8,7 @@
 #include "speakerdialog.h"
 #include "searchdialog.h"
 #include "listdialog.h"
+#include "bandpassdialog.h"
 #include "speaker.h"
 #include "sealedbox.h"
 #include "portedbox.h"
@@ -84,7 +85,17 @@ public slots:
     void onAlignBullock();
     void onAlignKeele_Hoge();
 
+    void onBandpassAlignment();
+    void onBandpassOptimizeRequested(double s, double pa);
+    void onBandpassOptimizeCancelled();
+
 protected:
+    void linkMenus();
+    void linkTabs();
+    void linkInternals();
+    void unlinkMenus();
+    void unlinkTabs();
+    void unlinkInternals();
     bool print(QPrinter* printer);
     void syncUiFromCurrentSpeaker(const Speaker &spk);
     void syncUiFromCurrentSealedBox(const SealedBox& box);
@@ -103,6 +114,7 @@ private:
     QFileDialog *fileDialog;
     SearchDialog *searchDialog;
     ListDialog *listDialog;
+    BandpassDialog *bandpassDialog;
 
     Speaker currentSpeaker;
     int currentSpeakerNumber;
