@@ -14,7 +14,7 @@ public:
 
     QDomElement toDomElement(QDomDocument& doc) const;
     void fromDomElement(const QDomElement& e);
-    void render(QPainter *painter, const QRectF& area);
+    void render(QPainter *painter, const QRectF& area) const;
 private:
     double volume;
 };
