@@ -9,7 +9,7 @@ SearchDialog::SearchDialog(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    QStringList params = QString("Fs,Qts,Vas,Sd,Re,Xmax").split(',');
+    QStringList params = QString("Fs,Qts,Vas,Dia,Z,Sd,Re,Xmax,Le,Qms,Qes,Spl,Pe,BL").split(',');
 
     ui->searchComboBox->addItems(params);
 
