@@ -1,5 +1,6 @@
 #include "speakerdb.h"
 
+#include <iostream>
 #include <QDebug>
 #include <QString>
 #include <QList>
@@ -283,6 +284,16 @@ QList<Speaker> SpeakerDb::getByFs(double min, double max)
     return getByValue("fs", min, max);
 }
 
+QList<Speaker> SpeakerDb::getByDia(double min, double max)
+{
+    return getByValue("dia", min, max);
+}
+
+QList<Speaker> SpeakerDb::getByZ(double min, double max)
+{
+    return getByValue("z", min, max);
+}
+
 QList<Speaker> SpeakerDb::getBySd(double min, double max)
 {
     return getByValue("sd", min, max);
@@ -298,6 +309,16 @@ QList<Speaker> SpeakerDb::getByQts(double min, double max)
     return getByValue("qts", min, max);
 }
 
+QList<Speaker> SpeakerDb::getByQes(double min, double max)
+{
+    return getByValue("qes", min, max);
+}
+
+QList<Speaker> SpeakerDb::getByQms(double min, double max)
+{
+    return getByValue("qms", min, max);
+}
+
 QList<Speaker> SpeakerDb::getByRe(double min, double max)
 {
     return getByValue("re", min, max);
@@ -308,6 +329,21 @@ QList<Speaker> SpeakerDb::getByXmax(double min, double max)
     return getByValue("xmax", min, max);
 }
 
+QList<Speaker> SpeakerDb::getBySpl(double min, double max)
+{
+    return getByValue("spl", min, max);
+}
+
+QList<Speaker> SpeakerDb::getByPe(double min, double max)
+{
+    return getByValue("pe", min, max);
+}
+
+QList<Speaker> SpeakerDb::getByBL(double min, double max)
+{
+    return getByValue("bl", min, max);
+}
+
 QList<QString> SpeakerDb::getVendors(void)
 {
     QString path = getPath();
