@@ -23,11 +23,19 @@ public:
 
     static QList<Speaker> getByVendor(const QString& vendor);
     static QList<Speaker> getByFs(double min, double max);
+    static QList<Speaker> getByDia(double min, double max);
+    static QList<Speaker> getByZ(double min, double max);
     static QList<Speaker> getBySd(double min, double max);
     static QList<Speaker> getByVas(double min, double max);
     static QList<Speaker> getByQts(double min, double max);
+    static QList<Speaker> getByQes(double min, double max);
+    static QList<Speaker> getByQms(double min, double max);
     static QList<Speaker> getByRe(double min, double max);
     static QList<Speaker> getByXmax(double min, double max);
+    static QList<Speaker> getBySpl(double min, double max);
+    static QList<Speaker> getByPe(double min, double max);
+    static QList<Speaker> getByBL(double min, double max);
+
     static QList<Speaker> getByValue(QString var, double min, double max);
 
     static bool merge(QFile& with);
